# SELF NOTE: Year X is Jan X to Dec X here. 
# This is NOT the same as in Brian K's analysis OR earlier versions of my seasonal forecast.

alter table april2009.regions drop column period;
alter table april2009.regions add column period char(2);
update april2009.regions set period="ES" where month(record_date)<=2 and halfhour_number>=15 and halfhour_number<=42;
update april2009.regions set period="S" where ((month(record_date)=5 and day(record_date)<10) or (month(record_date)>=3 and month(record_date)<=4)) and halfhour_number>=15 and halfhour_number<=42;
update april2009.regions set period="S" where ((month(record_date)=10 and day(record_date)>=20) or (month(record_date)>=11 and month(record_date)<=12)) and halfhour_number>=15 and halfhour_number<=42;
update april2009.regions set period="W" where period is null;
create index period on april2009.regions (period);

# Change Tiwai to 605 MW throughout
drop table if exists test.tiwai;
create table test.tiwai as select record_date, halfhour_number, val as tiwai from april2009.genload where id="TY_Total";
create index record_hh on test.tiwai (record_date, halfhour_number);
#create index halfhour_number on test.tiwai (halfhour_number)% superfluos, can be done with the one index provided left to right components are called (which they are)
drop table if exists test.regions;
create table test.regions as select a.*, b.tiwai from april2009.regions as a inner join test.tiwai as b on a.record_date=b.record_date and a.halfhour_number=b.halfhour_number;
#You can condense these into one index provided the correct order is used in specifying columns. Leaving them separate is more useful 
#for a range of queries but since we're only doing one consider using one index
create index period on test.regions (period);
create index record_date on test.regions (record_date);
create index region on test.regions (region);
update test.regions set offtake = offtake-tiwai+605000 where region="OtagoSouthlandPost96"; 

drop table if exists test.annual_peaks;
create table test.annual_peaks as 
select region, 
year(record_date) as year, 
max(if(period="ES",offtake,0)) as extreme_summer_peak, 
max(if(period="S",offtake,0)) as summer_peak, 
max(if(period="W",offtake,0)) as winter_peak, 
floor(sum(offtake)/count(offtake)) as average_power, 
floor(sum(offtake*(period="W"))/sum(period="W")) as winter_average_power, 
floor(sum(offtake*(period="S"))/sum(period="S")) as summer_average_power, 
floor(sum(offtake*(period="ES"))/sum(period="ES")) as extreme_summer_average_power
from test.regions 
where (record_date>="1997-01-01") group by region, year(record_date);

drop table if exists test.all_regions;
create table test.all_regions as select record_date, period, halfhour_number, sum(offtake) as offtake from test.regions group by record_date, period, halfhour_number;
drop table if exists test.annual_peaks_all;
create table test.annual_peaks_all as select year(record_date) as year, max(if(period="ES",offtake,0)) as extreme_summer_peak, max(if(period="S",offtake,0)) as summer_peak, max(if(period="W",offtake,0)) as winter_peak, floor(sum(offtake)/count(offtake)) as average_power, floor(sum(offtake*(period="W"))/sum(period="W")) as winter_average_power, floor(sum(offtake*(period="S"))/sum(period="S")) as summer_average_power, floor(sum(offtake*(period="ES"))/sum(period="ES")) as extreme_summer_average_power from test.all_regions where (record_date>="1997-01-01") group by year(record_date);

drop table if exists test.uni;
create table test.uni as select record_date, period, halfhour_number, sum(offtake) as offtake from test.regions where region in ("AucklandPost96", "NorthIsthmusPost96") group by record_date, period, halfhour_number;
drop table if exists test.annual_peaks_uni;
create table test.annual_peaks_uni as select year(record_date) as year, max(if(period="ES",offtake,0)) as extreme_summer_peak, max(if(period="S",offtake,0)) as summer_peak, max(if(period="W",offtake,0)) as winter_peak, floor(sum(offtake)/count(offtake)) as average_power, floor(sum(offtake*(period="W"))/sum(period="W")) as winter_average_power, floor(sum(offtake*(period="S"))/sum(period="S")) as summer_average_power, floor(sum(offtake*(period="ES"))/sum(period="ES")) as extreme_summer_average_power from test.uni where (record_date>="1997-01-01") group by year(record_date);

drop table if exists test.lni;
create table test.lni as select record_date, period, halfhour_number, sum(offtake) as offtake from test.regions where region in ("WaikatoPost96", "BayOfPlentyPost96", "CentralPost96", "HawkesBayPost96", "TaranakiPost96", "WellingtonPost96") group by record_date, period, halfhour_number;
drop table if exists test.annual_peaks_lni;
create table test.annual_peaks_lni as select year(record_date) as year, max(if(period="ES",offtake,0)) as extreme_summer_peak, max(if(period="S",offtake,0)) as summer_peak, max(if(period="W",offtake,0)) as winter_peak, floor(sum(offtake)/count(offtake)) as average_power, floor(sum(offtake*(period="W"))/sum(period="W")) as winter_average_power, floor(sum(offtake*(period="S"))/sum(period="S")) as summer_average_power, floor(sum(offtake*(period="ES"))/sum(period="ES")) as extreme_summer_average_power from test.lni where (record_date>="1997-01-01") group by year(record_date);

drop table if exists test.usi;
create table test.usi as select record_date, period, halfhour_number, sum(offtake) as offtake from test.regions where region in("NelsonMarlboroughPost96", "WestCoastPost96", "CanterburyPost96", "SouthCanterburyPost96") group by record_date, period, halfhour_number;
drop table if exists test.annual_peaks_usi;
create table test.annual_peaks_usi as select year(record_date) as year, max(if(period="ES",offtake,0)) as extreme_summer_peak, max(if(period="S",offtake,0)) as summer_peak, max(if(period="W",offtake,0)) as winter_peak, floor(sum(offtake)/count(offtake)) as average_power, floor(sum(offtake*(period="W"))/sum(period="W")) as winter_average_power, floor(sum(offtake*(period="S"))/sum(period="S")) as summer_average_power, floor(sum(offtake*(period="ES"))/sum(period="ES")) as extreme_summer_average_power from test.usi where (record_date>="1997-01-01") group by year(record_date);

drop table if exists test.lsi;
create table test.lsi as select record_date, period, halfhour_number, sum(offtake) as offtake from test.regions where region="OtagoSouthlandPost96" group by record_date, period, halfhour_number;
drop table if exists test.annual_peaks_lsi;
create table test.annual_peaks_lsi as select year(record_date) as year, max(if(period="ES",offtake,0)) as extreme_summer_peak, max(if(period="S",offtake,0)) as summer_peak, max(if(period="W",offtake,0)) as winter_peak, floor(sum(offtake)/count(offtake)) as average_power, floor(sum(offtake*(period="W"))/sum(period="W")) as winter_average_power, floor(sum(offtake*(period="S"))/sum(period="S")) as summer_average_power, floor(sum(offtake*(period="ES"))/sum(period="ES")) as extreme_summer_average_power from test.lsi where (record_date>="1997-01-01") group by year(record_date);

drop table if exists test.ni;
create table test.ni as select record_date, period, halfhour_number, sum(offtake) as offtake from test.regions where region="AucklandPost96" or region="NorthIsthmusPost96" or region="WaikatoPost96" or region="BayOfPlentyPost96" or region="CentralPost96" or region="HawkesBayPost96" or region="TaranakiPost96" or region="WellingtonPost96" group by record_date, period, halfhour_number;
drop table if exists test.annual_peaks_ni;
create table test.annual_peaks_ni as select year(record_date) as year, max(if(period="ES",offtake,0)) as extreme_summer_peak, max(if(period="S",offtake,0)) as summer_peak, max(if(period="W",offtake,0)) as winter_peak, floor(sum(offtake)/count(offtake)) as average_power, floor(sum(offtake*(period="W"))/sum(period="W")) as winter_average_power, floor(sum(offtake*(period="S"))/sum(period="S")) as summer_average_power, floor(sum(offtake*(period="ES"))/sum(period="ES")) as extreme_summer_average_power from test.ni where (record_date>="1997-01-01") group by year(record_date);

drop table if exists test.si;
create table test.si as select record_date, period, halfhour_number, sum(offtake) as offtake from test.regions where region="CanterburyPost96" or region="NelsonMarlboroughPost96" or region="OtagoSouthlandPost96" or region="SouthCanterburyPost96" or region="WestCoastPost96" group by record_date, period, halfhour_number;
drop table if exists test.annual_peaks_si;
create table test.annual_peaks_si as select year(record_date) as year, max(if(period="ES",offtake,0)) as extreme_summer_peak, max(if(period="S",offtake,0)) as summer_peak, max(if(period="W",offtake,0)) as winter_peak, floor(sum(offtake)/count(offtake)) as average_power, floor(sum(offtake*(period="W"))/sum(period="W")) as winter_average_power, floor(sum(offtake*(period="S"))/sum(period="S")) as summer_average_power, floor(sum(offtake*(period="ES"))/sum(period="ES")) as extreme_summer_average_power from test.si where (record_date>="1997-01-01") group by year(record_date);

# South Canterbury - 2006 winter figures look very dodgy (affected by outages?), 
#  replace 2006 winter peak with 2006 summer peak which is currently higher,
select summer_peak from test.annual_peaks where year = 2006 and region='SouthCanterburyPost96'; ##copy this result into next line. Can't self-reference table in an update clause.
update test.annual_peaks set winter_peak=(100838) where year=2006 and region='SouthCanterburyPost96';
select "Warning, check previous line";

# Taranaki - subtract Motunui plant from series before processing (as it is now switched off)
drop table if exists test.motunui;
create table test.motunui as select record_date, halfhour_number, val as offtake from april2009.genload where id="NI_Motunui";
create index record_hh on test.motunui (record_date, halfhour_number);
drop table if exists test.taranaki_less_motunui;
create table test.taranaki_less_motunui as select a.region, record_date, a.period, halfhour_number, a.offtake - b.offtake as offtake from test.regions as a inner join test.motunui as b using(halfhour_number, record_date) where a.region="TaranakiPost96";

drop table if exists test.annual_taranaki_peaks;
create table test.annual_taranaki_peaks as 
select region, year(record_date) as year, 
max(if(period="ES",offtake,0)) as extreme_summer_peak, 
max(if(period="S",offtake,0)) as summer_peak, 
max(if(period="W",offtake,0)) as winter_peak, 
floor(sum(offtake)/count(offtake)) as average_power, 
floor(sum(offtake*(period="W"))/sum(period="W")) as winter_average_power, 
floor(sum(offtake*(period="S"))/sum(period="S")) as summer_average_power, 
floor(sum(offtake*(period="ES"))/sum(period="ES")) as extreme_summer_average_power
from test.taranaki_less_motunui where (record_date>="1997-01-01") 
group by region, year(record_date);
#I replace the orignal taranki result with the updated one. This results in consistent code later. Maybe don't do this if orginal 
#Taranaki data is needed, but I don't think it is.
delete from test.annual_peaks
where region = 'taranakipost96';
insert into test.annual_peaks
select *
from test.annual_taranaki_peaks;
# Note also the large outlier in 2000 - this was caused by extreme weather - seems genuine, no action
# And fix the 2007 data - at time of press, 2007 winter peak was affected by bad data for Whareroa
#update test.annual_taranaki_peaks set winter_peak=131300 where year=2007; # Fixed with latest CDS data

drop table test.annual_peaks_actual_tiwai;
create table test.annual_peaks_actual_tiwai as 
select region, year(record_date) as year, 
max(if(period="ES",offtake,0)) as extreme_summer_peak, 
max(if(period="S",offtake,0)) as summer_peak, 
max(if(period="W",offtake,0)) as winter_peak, 
floor(sum(offtake)/count(offtake)) as average_power, 
floor(sum(offtake*(period="W"))/sum(period="W")) as winter_average_power, 
floor(sum(offtake*(period="S"))/sum(period="S")) as summer_average_power, 
floor(sum(offtake*(period="ES"))/sum(period="ES")) as extreme_summer_average_power
from april2009.regions 
where (record_date>="1997-01-01") group by region, year(record_date);

drop table if exists test.lsi_actual_tiwai;
create table test.lsi_actual_tiwai as select record_date, period, halfhour_number, sum(offtake) as offtake from april2009.regions where region="OtagoSouthlandPost96" group by record_date, period, halfhour_number;
drop table if exists test.annual_peaks_lsi_actual_tiwai;
create table test.annual_peaks_lsi_actual_tiwai as select year(record_date) as year, max(if(period="ES",offtake,0)) as extreme_summer_peak, max(if(period="S",offtake,0)) as summer_peak, max(if(period="W",offtake,0)) as winter_peak, floor(sum(offtake)/count(offtake)) as average_power, floor(sum(offtake*(period="W"))/sum(period="W")) as winter_average_power, floor(sum(offtake*(period="S"))/sum(period="S")) as summer_average_power, floor(sum(offtake*(period="ES"))/sum(period="ES")) as extreme_summer_average_power from test.lsi_actual_tiwai where (record_date>="1997-01-01") group by year(record_date);

drop table if exists test.si_actual_tiwai;
create table test.si_actual_tiwai as select record_date, period, halfhour_number, sum(offtake) as offtake from april2009.regions where region="CanterburyPost96" or region="NelsonMarlboroughPost96" or region="OtagoSouthlandPost96" or region="SouthCanterburyPost96" or region="WestCoastPost96" group by record_date, period, halfhour_number;
drop table if exists test.annual_peaks_si_actual_tiwai;
create table test.annual_peaks_si_actual_tiwai as select year(record_date) as year, max(if(period="ES",offtake,0)) as extreme_summer_peak, max(if(period="S",offtake,0)) as summer_peak, max(if(period="W",offtake,0)) as winter_peak, floor(sum(offtake)/count(offtake)) as average_power, floor(sum(offtake*(period="W"))/sum(period="W")) as winter_average_power, floor(sum(offtake*(period="S"))/sum(period="S")) as summer_average_power, floor(sum(offtake*(period="ES"))/sum(period="ES")) as extreme_summer_average_power from test.si_actual_tiwai where (record_date>="1997-01-01") group by year(record_date);

drop table if exists test.all_regions_actual_tiwai;
create table test.all_regions_actual_tiwai as select record_date, period, halfhour_number, sum(offtake) as offtake from april2009.regions group by record_date, period, halfhour_number;
drop table if exists test.annual_peaks_all_actual_tiwai;
create table test.annual_peaks_all_actual_tiwai as select year(record_date) as year, max(if(period="ES",offtake,0)) as extreme_summer_peak, max(if(period="S",offtake,0)) as summer_peak, max(if(period="W",offtake,0)) as winter_peak, floor(sum(offtake)/count(offtake)) as average_power, floor(sum(offtake*(period="W"))/sum(period="W")) as winter_average_power, floor(sum(offtake*(period="S"))/sum(period="S")) as summer_average_power, floor(sum(offtake*(period="ES"))/sum(period="ES")) as extreme_summer_average_power from test.all_regions_actual_tiwai where (record_date>="1997-01-01") group by year(record_date);

# need to be root to do the following
# ALSO NEED TO DELETE THESE FILES, IT DOESN'T REPLACE THEM IF THEY EXIST
select year,summer_peak,extreme_summer_peak,winter_peak,average_power,summer_average_power,extreme_summer_average_power,winter_average_power from test.annual_peaks where region="AucklandPost96" into outfile "x:\\rproject\\seasonal_peaks_Auckland.txt";
select year,summer_peak,extreme_summer_peak,winter_peak,average_power,summer_average_power,extreme_summer_average_power,winter_average_power into outfile "f:\\rproject\\seasonal_peaks_BayOfPlenty.txt" from test.annual_peaks where region="BayOfPlentyPost96";
select year,summer_peak,extreme_summer_peak,winter_peak,average_power,summer_average_power,extreme_summer_average_power,winter_average_power into outfile "f:\\rproject\\seasonal_peaks_Canterbury.txt" from test.annual_peaks where region="CanterburyPost96";
select year,summer_peak,extreme_summer_peak,winter_peak,average_power,summer_average_power,extreme_summer_average_power,winter_average_power into outfile "f:\\rproject\\seasonal_peaks_Central.txt" from test.annual_peaks where region="CentralPost96";
select year,summer_peak,extreme_summer_peak,winter_peak,average_power,summer_average_power,extreme_summer_average_power,winter_average_power into outfile "f:\\rproject\\seasonal_peaks_HawkesBay.txt" from test.annual_peaks where region="HawkesBayPost96";
select year,summer_peak,extreme_summer_peak,winter_peak,average_power,summer_average_power,extreme_summer_average_power,winter_average_power into outfile "f:\\rproject\\seasonal_peaks_NelsonMarlborough.txt" from test.annual_peaks where region="NelsonMarlboroughPost96";
select year,summer_peak,extreme_summer_peak,winter_peak,average_power,summer_average_power,extreme_summer_average_power,winter_average_power into outfile "f:\\rproject\\seasonal_peaks_NorthIsthmus.txt" from test.annual_peaks where region="NorthIsthmusPost96";
select year,summer_peak,extreme_summer_peak,winter_peak,average_power,summer_average_power,extreme_summer_average_power,winter_average_power into outfile "f:\\rproject\\seasonal_peaks_OtagoSouthland.txt" from test.annual_peaks where region="OtagoSouthlandPost96";
select year,summer_peak,extreme_summer_peak,winter_peak,average_power,summer_average_power,extreme_summer_average_power,winter_average_power into outfile "f:\\rproject\\seasonal_peaks_SouthCanterbury.txt" from test.annual_peaks where region="SouthCanterburyPost96";
select year,summer_peak,extreme_summer_peak,winter_peak,average_power,summer_average_power,extreme_summer_average_power,winter_average_power into outfile "f:\\rproject\\seasonal_peaks_Waikato.txt" from test.annual_peaks where region="WaikatoPost96";
select year,summer_peak,extreme_summer_peak,winter_peak,average_power,summer_average_power,extreme_summer_average_power,winter_average_power into outfile "f:\\rproject\\seasonal_peaks_Wellington.txt" from test.annual_peaks where region="WellingtonPost96";
select year,summer_peak,extreme_summer_peak,winter_peak,average_power,summer_average_power,extreme_summer_average_power,winter_average_power into outfile "f:\\rproject\\seasonal_peaks_WestCoast.txt" from test.annual_peaks where region="WestCoastPost96";
select year,summer_peak,extreme_summer_peak,winter_peak,average_power,summer_average_power,extreme_summer_average_power,winter_average_power into outfile "f:\\rproject\\seasonal_peaks_Taranaki.txt" from test.annual_peaks where region="TaranakiPost96";
select year,summer_peak,extreme_summer_peak,winter_peak,average_power,summer_average_power,extreme_summer_average_power,winter_average_power into outfile "f:\\rproject\\seasonal_peaks_all.txt" from test.annual_peaks_all;
select year,summer_peak,extreme_summer_peak,winter_peak,average_power,summer_average_power,extreme_summer_average_power,winter_average_power into outfile "f:\\rproject\\seasonal_peaks_uni.txt" from test.annual_peaks_uni;
select year,summer_peak,extreme_summer_peak,winter_peak,average_power,summer_average_power,extreme_summer_average_power,winter_average_power into outfile "f:\\rproject\\seasonal_peaks_usi.txt" from test.annual_peaks_usi;
select year,summer_peak,extreme_summer_peak,winter_peak,average_power,summer_average_power,extreme_summer_average_power,winter_average_power into outfile "f:\\rproject\\seasonal_peaks_lni.txt" from test.annual_peaks_lni;
select year,summer_peak,extreme_summer_peak,winter_peak,average_power,summer_average_power,extreme_summer_average_power,winter_average_power into outfile "f:\\rproject\\seasonal_peaks_lsi.txt" from test.annual_peaks_lsi;
select year,summer_peak,extreme_summer_peak,winter_peak,average_power,summer_average_power,extreme_summer_average_power,winter_average_power into outfile "f:\\rproject\\seasonal_peaks_ni.txt" from test.annual_peaks_ni;
select year,summer_peak,extreme_summer_peak,winter_peak,average_power,summer_average_power,extreme_summer_average_power,winter_average_power into outfile "f:\\rproject\\seasonal_peaks_si.txt" from test.annual_peaks_si;
# Tiwai modified output
select year,summer_peak,extreme_summer_peak,winter_peak,average_power,summer_average_power,extreme_summer_average_power,winter_average_power into outfile "f:\\rproject\\seasonal_peaks_OtagoSouthland_actual_tiwai.txt" from test.annual_peaks_actual_tiwai where region="OtagoSouthlandPost96";
select year,summer_peak,extreme_summer_peak,winter_peak,average_power,summer_average_power,extreme_summer_average_power,winter_average_power into outfile "f:\\rproject\\seasonal_peaks_all_actual_tiwai.txt" from test.annual_peaks_all_actual_tiwai;
select year,summer_peak,extreme_summer_peak,winter_peak,average_power,summer_average_power,extreme_summer_average_power,winter_average_power into outfile "f:\\rproject\\seasonal_peaks_lsi_actual_tiwai.txt" from test.annual_peaks_lsi_actual_tiwai;
select year,summer_peak,extreme_summer_peak,winter_peak,average_power,summer_average_power,extreme_summer_average_power,winter_average_power into outfile "f:\\rproject\\seasonal_peaks_si_actual_tiwai.txt" from test.annual_peaks_si_actual_tiwai;

